@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Any;
 
-our $DATE = '2015-02-06'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-04-12'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -70,7 +70,7 @@ Perinci::CmdLine::Any - Choose Perinci::CmdLine implementation (::Lite or ::Clas
 
 =head1 VERSION
 
-This document describes version 0.09 of Perinci::CmdLine::Any (from Perl distribution Perinci-CmdLine-Any), released on 2015-02-06.
+This document describes version 0.10 of Perinci::CmdLine::Any (from Perl distribution Perinci-CmdLine-Any), released on 2015-04-12.
 
 =head1 SYNOPSIS
 
@@ -81,7 +81,7 @@ In your command-line script (this will pick ::Lite first):
  Perinci::CmdLine::Any->new(url => '/Package/func')->run;
 
 In your command-line script (this will pick ::Classic first, and falls back to
-::Classic):
+::Lite):
 
  #!perl
  use Perinci::CmdLine::Any -prefer_lite=>0;
